==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/et/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'kasutaja saab sisse logida',
    'activated_disabled_help_text' => 'Te ei saa iseenda konto aktiveerimis staatust muuta.',
    'assets_user'       => 'Kasutajaga :nimi seotud vahendid',
    'bulk_update_warn'	=> 'Sa oled muutmas :user_count kasutaja andmeid. Palun pane tähele, et saa ei saa selle vormi kaudu muuta enda kasutaja andmeid, neid pead muutma eraldi.',
    'bulk_update_help'	=> 'Selle vormiga saad muuta mitmeid kasutajaid korraga. Täida ainult need väljad, mida on vaja muuta. Tühjaks jäetud väljasid ei muudeta.',
    'current_assets'    => 'Selle kasutaja valduses olevad vahendid',
    'clone'             => 'Klooni kasutaja',
    'contact_user'      => 'Võta ühendust :name-ga',
    'edit'              => 'Muuda kasutajat',
    'filetype_info'     => 'Lubatud failitüübid on png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ja rar.',
    'history_user'      => 'Kasutaja :name ajalugu',
	'info'				=> 'Info',
    'restore_user'		=> 'Nende taastamiseks klõpsake siin.',
    'last_login'        => 'Viimane sisselogimine',
    'ldap_config_text'  => 'LDAP-i konfiguratsiooniseadeid saab leida Admin> Seaded. (Valikuline) valitud asukoht määratakse kõigi imporditud kasutajate jaoks.',
    'print_assigned'    => 'Prindi kõik varad',
    'software_user'     => 'Kasutaja :name valdusesse antud tarkvara',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Vaata kasutajat :name',
    'usercsv'           => 'CSV fail',
    'two_factor_admin_optin_help' => 'Sinu praegused admin seaded lubavad kahe-astmelist autantimis jõustada valikulselt. ',
    'two_factor_enrolled' => '2FA-seade on registreeritud',
    'two_factor_active'   => '2FA aktiivne ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/et/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'kasutaja saab sisse logida',
    'activated_disabled_help_text' => 'Te ei saa iseenda konto aktiveerimis staatust muuta.',
    'assets_user'       => 'Kasutajaga :nimi seotud vahendid',
    'bulk_update_warn'	=> 'Sa oled muutmas :user_count kasutaja andmeid. Palun pane tähele, et saa ei saa selle vormi kaudu muuta enda kasutaja andmeid, neid pead muutma eraldi.',
    'bulk_update_help'	=> 'Selle vormiga saad muuta mitmeid kasutajaid korraga. Täida ainult need väljad, mida on vaja muuta. Tühjaks jäetud väljasid ei muudeta.',
    'current_assets'    => 'Selle kasutaja valduses olevad vahendid',
    'clone'             => 'Klooni kasutaja',
    'contact_user'      => 'Võta ühendust :name-ga',
    'edit'              => 'Muuda kasutajat',
    'filetype_info'     => 'Lubatud failitüübid on png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ja rar.',
    'history_user'      => 'Kasutaja :name ajalugu',
    'info'				=> 'Info',
    'restore_user'		=> 'Nende taastamiseks klõpsake siin.',
    'last_login'        => 'Viimane sisselogimine',
    'ldap_config_text'  => 'LDAP-i konfiguratsiooniseadeid saab leida Admin> Seaded. (Valikuline) valitud asukoht määratakse kõigi imporditud kasutajate jaoks.',
    'print_assigned'    => 'Prindi kõik varad',
    'software_user'     => 'Kasutaja :name valdusesse antud tarkvara',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Vaata kasutajat :name',
    'usercsv'           => 'CSV fail',
    'two_factor_admin_optin_help' => 'Sinu praegused admin seaded lubavad kahe-astmelist autantimis jõustada valikulselt. ',
    'two_factor_enrolled' => '2FA-seade on registreeritud',
    'two_factor_active'   => '2FA aktiivne ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
